@@ -5,16 +5,16 @@ use warnings;
 require Exporter ;
 use bytes;
 
-use IO::Compress::Base;
+use IO::Compress::Base 2.003 ;
 
-use IO::Compress::Base::Common qw(createSelfTiedObject);
-use IO::Compress::Adapter::LZO ;
+use IO::Compress::Base::Common  2.003 qw(createSelfTiedObject);
+use IO::Compress::Adapter::LZO  2.003 ;
 use Compress::LZO qw(crc32 adler32 LZO_VERSION);
-use IO::Compress::Lzop::Constants ;
+use IO::Compress::Lzop::Constants  2.003 ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $LzopError);
 
-$VERSION = '2.002';
+$VERSION = '2.003';
 $LzopError = '';
 
 @ISA    = qw(Exporter IO::Compress::Base);
@@ -160,7 +160,7 @@ sub getExtraParams
 {
     my $self = shift ;
 
-    use IO::Compress::Base::Common qw(:Parse);
+    use IO::Compress::Base::Common  2.003 qw(:Parse);
     
     return (
             'Name'      => [0, 1, Parse_any,       undef],
@@ -938,7 +938,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2006 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2007 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
