@@ -4,11 +4,11 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common qw(:Status);
+use IO::Compress::Base::Common  2.003 qw(:Status);
 use Compress::LZO ;
 
 our ($VERSION, @ISA);
-$VERSION = '2.002';
+$VERSION = '2.003';
 
 
 sub mkUncompObject
