@@ -4,18 +4,18 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common qw(:Status createSelfTiedObject);
+use IO::Compress::Base::Common  2.003 qw(:Status createSelfTiedObject);
 
-use IO::Uncompress::Base ;
-use IO::Uncompress::Adapter::LZO ;
+use IO::Uncompress::Base  2.003 ;
+use IO::Uncompress::Adapter::LZO  2.003 ;
 use Compress::LZO qw(crc32 adler32);
-use IO::Compress::Lzop::Constants ;
+use IO::Compress::Lzop::Constants  2.003 ;
 
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnLzopError);
 
-$VERSION = '2.002';
+$VERSION = '2.003';
 $UnLzopError = '';
 
 @ISA    = qw( Exporter IO::Uncompress::Base );
@@ -1110,7 +1110,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2006 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2007 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
